CertChainRef

Struct CertChainRef 

pub struct CertChainRef<'a> { /* private fields */ }
Available on crate feature manifest only.
A reference to a byte slice that is expected to be a valid sequence of DER-encoded X.509 certificates.

This is used to store a chain of certificates in an Image4 manifests without actually parsing them. There are two reasons for this:

  1. The library currently uses the x509_cert crate to decode the certificates and that means the original signed TBS certificates are lost when a manifest is decoded. Verifying the manifest’s certificate chain isn’t possible in that case.
  2. Parsing the certificates requires processing time and memory. There is no reason to do this, for example, when all you want to do is to encode them back into DER and write to another file.

Implementations

Source

impl<'a> CertChainRef<'a>

pub fn as_bytes(&self) -> &'a [u8]

Returns the contents of the body as a byte slice.

pub fn len(&self) -> Length

Returns the length of the body.

pub fn is_empty(&self) -> bool

Returns true if the body is empty.

Source

impl CertChainRef<'_>

pub fn decode_body(&self) -> Result<Vec<Certificate>>

Available on crate feature x509-cert only.

Decodes the body as a vector of Certificates.

Source

impl CertChainRef<'_>

pub fn iter(&self) -> CertIter<'_>

Returns iterator over individual certificates in the chain.