UnsignedManifestRef

Struct UnsignedManifestRef 

pub struct UnsignedManifestRef<'a> { /* private fields */ }
Available on crate feature manifest only.
An unsigned Image4 manifest that doesn’t own its contents.

Validation

The manifest’s body IS NOT required to be valid.

Currently the only way to check that an UnsignedManifestRef contains valid data is to decode its body using the UnsignedManifestRef::decode_body method.

Implementations

Source

impl<'a> UnsignedManifestRef<'a>

pub fn new(body: DictRef<'a>) -> Self

Creates a new unsigned manifest from its body contents.

pub fn decode_after_magic<R: Reader<'a>>(decoder: &mut R) -> Result<Self>

Decodes the part of an unsigned manifest after the magic string.

May be used when it is required to first identify what kind of buffer you’re looking at by checking the magic string.

pub fn version(&self) -> u32

Returns the manifest’s version.

pub fn body(&self) -> &DictRef<'a>

Returns a reference to the manifest’s body.

pub fn decode_body(&self) -> Result<BTreeMap<Tag, Value>>

Available on crate feature alloc only.

Decodes the manifest’s body into a BTreeMap describing its properties.

pub fn sign<K: Signer<S>, S: SignatureEncoding>( &self, key: &K, cert_chain: impl Into<CertChain>, ) -> Result<Manifest, SigningError>

Available on crate feature signature only.

Signs an unsigned manifest with the specified key and certificate chain.