pub struct CertChainRef<'a> { /* private fields */ }Available on crate feature
manifest only.Expand description
A reference to a byte slice that is expected to be a valid sequence of DER-encoded X.509 certificates.
This is used to store a chain of certificates in an Image4 manifests without actually parsing them. There are two reasons for this:
- The library currently uses the
x509_certcrate to decode the certificates and that means the original signed TBS certificates are lost when a manifest is decoded. Verifying the manifest’s certificate chain isn’t possible in that case. - Parsing the certificates requires processing time and memory. There is no reason to do this, for example, when all you want to do is to encode them back into DER and write to another file.
Implementations
Sourceimpl<'a> CertChainRef<'a>
impl<'a> CertChainRef<'a>
Sourceimpl CertChainRef<'_>
impl CertChainRef<'_>
Sourcepub fn decode_body(&self) -> Result<Vec<Certificate>>
Available on crate feature x509-cert only.
pub fn decode_body(&self) -> Result<Vec<Certificate>>
x509-cert only.Decodes the body as a vector of Certificates.
Sourceimpl CertChainRef<'_>
impl CertChainRef<'_>