pub struct UnsignedManifestRef<'a> { /* private fields */ }Available on crate feature
manifest only.Expand description
An unsigned Image4 manifest that doesn’t own its contents.
Validation
The manifest’s body IS NOT required to be valid.
Currently the only way to check that an UnsignedManifestRef contains valid data is to decode
its body using the UnsignedManifestRef::decode_body method.
Implementations
Sourceimpl<'a> UnsignedManifestRef<'a>
impl<'a> UnsignedManifestRef<'a>
Sourcepub fn decode_after_magic<R: Reader<'a>>(decoder: &mut R) -> Result<Self>
pub fn decode_after_magic<R: Reader<'a>>(decoder: &mut R) -> Result<Self>
Decodes the part of an unsigned manifest after the magic string.
May be used when it is required to first identify what kind of buffer you’re looking at by checking the magic string.
Sourcepub fn decode_body(&self) -> Result<BTreeMap<Tag, Value>>
Available on crate feature alloc only.
pub fn decode_body(&self) -> Result<BTreeMap<Tag, Value>>
alloc only.Decodes the manifest’s body into a BTreeMap describing its properties.
Sourcepub fn sign<K: Signer<S>, S: SignatureEncoding>(
&self,
key: &K,
cert_chain: impl Into<CertChain>,
) -> Result<Manifest, SigningError>
Available on crate feature signature only.
pub fn sign<K: Signer<S>, S: SignatureEncoding>( &self, key: &K, cert_chain: impl Into<CertChain>, ) -> Result<Manifest, SigningError>
signature only.Signs an unsigned manifest with the specified key and certificate chain.